@@ -16,18 +16,18 @@ from datetime import datetime
 from typing import Any, Dict, List
 
 from .literals import (
-    ActionCategory,
-    ActionConfigurationPropertyType,
-    ActionExecutionStatus,
-    ActionOwner,
-    ApprovalStatus,
-    ExecutorType,
-    FailureType,
-    JobStatus,
-    PipelineExecutionStatus,
-    StageExecutionStatus,
-    TriggerType,
-    WebhookAuthenticationType,
+    ActionCategoryType,
+    ActionConfigurationPropertyTypeType,
+    ActionExecutionStatusType,
+    ActionOwnerType,
+    ApprovalStatusType,
+    ExecutorTypeType,
+    FailureTypeType,
+    JobStatusType,
+    PipelineExecutionStatusType,
+    StageExecutionStatusType,
+    TriggerTypeType,
+    WebhookAuthenticationTypeType,
 )
 
 if sys.version_info >= (3, 8):
@@ -150,7 +150,7 @@ AWSSessionCredentialsTypeDef = TypedDict(
 AcknowledgeJobOutputTypeDef = TypedDict(
     "AcknowledgeJobOutputTypeDef",
     {
-        "status": JobStatus,
+        "status": JobStatusType,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -158,7 +158,7 @@ AcknowledgeJobOutputTypeDef = TypedDict(
 AcknowledgeThirdPartyJobOutputTypeDef = TypedDict(
     "AcknowledgeThirdPartyJobOutputTypeDef",
     {
-        "status": JobStatus,
+        "status": JobStatusType,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -177,7 +177,7 @@ _OptionalActionConfigurationPropertyTypeDef = TypedDict(
     {
         "queryable": bool,
         "description": str,
-        "type": ActionConfigurationPropertyType,
+        "type": ActionConfigurationPropertyTypeType,
     },
     total=False,
 )
@@ -244,7 +244,7 @@ ActionExecutionDetailTypeDef = TypedDict(
         "actionName": str,
         "startTime": datetime,
         "lastUpdateTime": datetime,
-        "status": ActionExecutionStatus,
+        "status": ActionExecutionStatusType,
         "input": "ActionExecutionInputTypeDef",
         "output": "ActionExecutionOutputTypeDef",
     },
@@ -297,7 +297,7 @@ ActionExecutionTypeDef = TypedDict(
     "ActionExecutionTypeDef",
     {
         "actionExecutionId": str,
-        "status": ActionExecutionStatus,
+        "status": ActionExecutionStatusType,
         "summary": str,
         "lastStatusChange": datetime,
         "token": str,
@@ -370,7 +370,7 @@ _RequiredActionTypeExecutorTypeDef = TypedDict(
     "_RequiredActionTypeExecutorTypeDef",
     {
         "configuration": "ExecutorConfigurationTypeDef",
-        "type": ExecutorType,
+        "type": ExecutorTypeType,
     },
 )
 _OptionalActionTypeExecutorTypeDef = TypedDict(
@@ -392,8 +392,8 @@ class ActionTypeExecutorTypeDef(
 ActionTypeIdTypeDef = TypedDict(
     "ActionTypeIdTypeDef",
     {
-        "category": ActionCategory,
-        "owner": ActionOwner,
+        "category": ActionCategoryType,
+        "owner": ActionOwnerType,
         "provider": str,
         "version": str,
     },
@@ -402,7 +402,7 @@ ActionTypeIdTypeDef = TypedDict(
 ActionTypeIdentifierTypeDef = TypedDict(
     "ActionTypeIdentifierTypeDef",
     {
-        "category": ActionCategory,
+        "category": ActionCategoryType,
         "owner": str,
         "provider": str,
         "version": str,
@@ -489,7 +489,7 @@ ApprovalResultTypeDef = TypedDict(
     "ApprovalResultTypeDef",
     {
         "summary": str,
-        "status": ApprovalStatus,
+        "status": ApprovalStatusType,
     },
 )
 
@@ -639,7 +639,7 @@ ExecutionDetailsTypeDef = TypedDict(
 ExecutionTriggerTypeDef = TypedDict(
     "ExecutionTriggerTypeDef",
     {
-        "triggerType": TriggerType,
+        "triggerType": TriggerTypeType,
         "triggerDetail": str,
     },
     total=False,
@@ -657,7 +657,7 @@ ExecutorConfigurationTypeDef = TypedDict(
 _RequiredFailureDetailsTypeDef = TypedDict(
     "_RequiredFailureDetailsTypeDef",
     {
-        "type": FailureType,
+        "type": FailureTypeType,
         "message": str,
     },
 )
@@ -922,7 +922,7 @@ PipelineExecutionSummaryTypeDef = TypedDict(
     "PipelineExecutionSummaryTypeDef",
     {
         "pipelineExecutionId": str,
-        "status": PipelineExecutionStatus,
+        "status": PipelineExecutionStatusType,
         "startTime": datetime,
         "lastUpdateTime": datetime,
         "sourceRevisions": List["SourceRevisionTypeDef"],
@@ -938,7 +938,7 @@ PipelineExecutionTypeDef = TypedDict(
         "pipelineName": str,
         "pipelineVersion": int,
         "pipelineExecutionId": str,
-        "status": PipelineExecutionStatus,
+        "status": PipelineExecutionStatusType,
         "statusSummary": str,
         "artifactRevisions": List["ArtifactRevisionTypeDef"],
     },
@@ -1096,7 +1096,7 @@ StageExecutionTypeDef = TypedDict(
     "StageExecutionTypeDef",
     {
         "pipelineExecutionId": str,
-        "status": StageExecutionStatus,
+        "status": StageExecutionStatusType,
     },
 )
 
@@ -1213,7 +1213,7 @@ WebhookDefinitionTypeDef = TypedDict(
         "targetPipeline": str,
         "targetAction": str,
         "filters": List["WebhookFilterRuleTypeDef"],
-        "authentication": WebhookAuthenticationType,
+        "authentication": WebhookAuthenticationTypeType,
         "authenticationConfiguration": "WebhookAuthConfigurationTypeDef",
     },
 )
